# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Container(_OnPrem):
    _type = "container"
    _icon_dir = "resources/onprem/container"


class Docker(_Container):
    _icon = "docker.png"


class Rkt(_Container):
    _icon = "rkt.png"


# Aliases

RKT = Rkt
