# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Connectivity(_OCI):
    _type = "connectivity"
    _icon_dir = "resources/oci/connectivity"


class Backbone(_Connectivity):
    _icon = "backbone.png"


class Customerdatacenter(_Connectivity):
    _icon = "customerdatacenter.png"


class Customerpremisesequip(_Connectivity):
    _icon = "customerpremisesequip.png"


class Fastconnect(_Connectivity):
    _icon = "fastconnect.png"


class Vpn(_Connectivity):
    _icon = "vpn.png"


# Aliases
